@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: control.h,v 1.1 94/04/26 20:07:14 nau Exp $
+ *  RCS: $Header: control.h,v 2.1 94/09/28 14:26:05 nau Exp $
  */
 
 /* prototypes for dialog routines
@@ -33,7 +33,10 @@
 
 #include "global.h"
 
-Widget		InitControlPanel(Widget, Widget, Widget);
-void		UpdateControlPanel(void);
+Widget	InitModeButtons(Widget, Widget, Widget);
+void	InitControlPanel(Widget, Widget, Widget);
+void	UpdateControlPanel(void);
+void	UpdateModeSelection(void);
+void	InstallControlAccelerators(void);
 
 #endif
