@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: error.h,v 1.1 94/04/26 20:07:18 nau Exp $
+ *  RCS: $Header: error.h,v 2.1 94/09/28 14:26:09 nau Exp $
  */
 
 /* prototypes for error and debug functions
@@ -37,12 +37,14 @@
 #define	STATUS_BREAK	1
 #define	STATUS_ERROR	-1
 
-void	Debug();
-void	MyWarning();
-void	MyWarningDialog();
+void	Message();
+void	OpenErrorMessage(char *);
+void	PopenErrorMessage(char *);
+void	OpendirErrorMessage(char *);
+void	ChdirErrorMessage(char *);
 void	MyFatal();
-
+void	CatchSignal(int);
 void	X11ErrorHandler(String);
-void	DebugEvent(XEvent *);
+void	InitErrorLog(void);
 
 #endif
