@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: file.h,v 1.3 94/05/29 15:27:42 nau Exp $
+ *  RCS: $Header: file.h,v 2.1 94/09/28 14:26:10 nau Exp $
  */
 
 /* prototypes for file routines
@@ -31,10 +31,11 @@
 #ifndef	__FILE_INCLUDED__
 #define	__FILE_INCLUDED__
 
+#include <stdio.h>			/* needed to define 'FILE *' */
 #include "global.h"
 
+FILE		*OpenConnectionDataFile(void);
 int			SavePCB(char *);
-int			LoadMarkedElement(char *);
 int			LoadPCB(char *);
 void		Backup(void);
 void		EmergencySave(void);
