@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: find.h,v 1.1 94/04/26 20:07:19 nau Exp $
+ *  RCS: $Header: find.h,v 2.1 94/09/28 14:26:11 nau Exp $
  */
 
 /* prototypes connection search routines
@@ -31,14 +31,20 @@
 #ifndef	__FIND_INCLUDED__
 #define	__FIND_INCLUDED__
 
-#include <stdio.h>
-
+#include <stdio.h>		/* needed to define 'FILE *' */
 #include "global.h"
 
-void		ResetFoundLinesAndRectangles(void);
-void		ResetFoundPinsAndVias(void);
-Cardinal	FindConnection(Position, Position);
-void		FindElementConnections(ElementTypePtr, FILE *);
-void		FindConnectionsToAllElements(FILE *);
+/* ---------------------------------------------------------------------------
+ * some local defines
+ */
+#define	LOOKUP_TYPES	\
+	(VIA_TYPE | PIN_TYPE | LINE_TYPE | POLYGON_TYPE )
+
+void	LookupElementConnections(ElementTypePtr, FILE *);
+void	LookupConnectionsToAllElements(FILE *);
+void	LookupConnection(Position, Position);
+void	LookupUnusedPins(FILE *);
+void	ResetFoundLinesAndPolygons(void);
+void	ResetFoundPinsAndVias(void);
 
 #endif
