@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: parse_l.h,v 1.1 94/04/26 20:07:22 nau Exp $
+ *  RCS: $Header: parse_l.h,v 2.1 94/09/28 14:26:58 nau Exp $
  */
 
 /* just defines common parser identifiers
@@ -33,13 +33,6 @@
 
 #include "global.h"
 
-/* ---------------------------------------------------------------------------
- * some local defines for the parse
- */
-#define	PARSE_PCB		0
-#define	PARSE_ELEMENT	1
-#define	PARSE_FONT		2
-
 int		ParsePCB(PCBTypePtr, char *);
 int		ParseElement(ElementTypePtr, char *);
 int		ParseFont(FontTypePtr, char *);
