@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: print.h,v 1.1 94/04/26 20:07:24 nau Exp $
+ *  RCS: $Header: /sda4/users/nau/src/pcb/RCS/print.h,v 2.3 1994/10/29 17:26:10 nau Exp $
  */
 
 /* prototypes for printing routines
@@ -35,6 +35,6 @@
 
 #include "global.h"
 
-int		PrintPS(int, char **, FILE *);
+int		PrintPS(char *, float, Boolean, Boolean, Boolean, Boolean, Position, Position);
 
 #endif
