@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  PCB, interactive printed circuit board design
- *  Copyright (C) 1994 Thomas Nau
+ *  Copyright (C) 1994,1995 Thomas Nau
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,12 +20,12 @@
  *
  *  Contact addresses for paper mail and Email:
  *  Thomas Nau, Schlehenweg 15, 88471 Baustetten, Germany
- *  Thomas.Nau@medizin.uni-ulm.de
+ *  Thomas.Nau@rz.uni-ulm.de
  *
- *  RCS: $Header: remove.h,v 1.1 94/04/26 20:07:24 nau Exp $
+ *  RCS: $Header: remove.h,v 2.1 94/09/28 14:27:01 nau Exp $
  */
 
-/* prototypes for create routines
+/* prototypes for remove routines
  */
 
 #ifndef	__REMOVE_INCLUDED__
@@ -33,12 +33,17 @@
 
 #include "global.h"
 
-void	RemovePCB(PCBTypePtr);
-Boolean	RemoveVia(PinTypePtr);
-Boolean	RemoveLine(LayerTypePtr, LineTypePtr);
-Boolean	RemoveRect(LayerTypePtr, RectTypePtr);
-Boolean	RemoveText(LayerTypePtr, TextTypePtr);
-Boolean	RemoveElement(ElementTypePtr);
-Boolean	RemoveAllInRectangle(Position, Position, Position, Position);
+/* ---------------------------------------------------------------------------
+ * some constants
+ */
+#define REMOVE_TYPES            \
+	(VIA_TYPE | LINE_TYPE | TEXT_TYPE | ELEMENT_TYPE | POLYGON_TYPE)
 
+
+void	ClearRemoveList(void);
+void	RemovePCB(PCBTypePtr);
+Boolean	RemoveSelected(void);
+void	RemoveObject(int, void *, void *);
+void	DestroyObject(int, void *, void *);
+ 
 #endif
